@@ -1,3 +1,4 @@
+from finam.access.access_token import TokenClient
 from finam.events.event import EventClient
 from finam.order.order import OrderClient
 from finam.portfolio.portfolio import PortfolioClient
@@ -10,3 +11,4 @@ class Client:
         self.securities = SecurityClient(token)
         self.orders = OrderClient(token)
         self.event = EventClient(token)
+        self.access_tokens = TokenClient(token)
